@@ -103,9 +103,9 @@ class DM(object):
             origin = copy.deepcopy(self.dict_response['distance']['value'][self.origins[origin_index]])
 
         tmp_origin = copy.deepcopy(origin)
-        if max_distance:
+        if max_distance is not None:
             for k, v in tmp_origin.iteritems():
-                if v > max_distance:
+                if v > max_distance or v == 'ZERO_RESULTS':
                     del(origin[k])
 
         return origin
